@@ -1,14 +1,11 @@
 package uk.ac.cam.ch.wwmm.opsin;
 
 
-import static org.junit.Assert.*;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.util.List;
 
-import org.junit.Test;
-
-import uk.ac.cam.ch.wwmm.opsin.Fragment;
-import uk.ac.cam.ch.wwmm.opsin.NameToStructure;
+import org.junit.jupiter.api.Test;
 
 public class SSSRTest {
 	
